@@ -4,14 +4,23 @@
 
 import os
 import subprocess
-import sys
 import argparse
+import logging
 
 import yaml
 import bids
 from snakemake import get_argument_parser
 
 bids.config.set_option("extension_initial_dot", True)
+logger = logging.Logger(__name__)
+
+
+class ConfigError(Exception):
+    """Exception raised for errors with the Snakebids config."""
+
+    def __init__(self, msg):
+        self.msg = msg
+        Exception.__init__()
 
 
 class KeyValue(argparse.Action):
@@ -28,6 +37,14 @@ class KeyValue(argparse.Action):
             getattr(namespace, self.dest)[key] = value
 
 
+class SnakemakeHelpAction(argparse.Action):
+    """Class for printing snakemake usage in argparse"""
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        run("snakemake -h")
+        sys.exit(0)
+
+
 def run(command, env=None):
     """Helper function for running a system command while merging
     stderr/stdout to stdout.
@@ -114,13 +131,11 @@ class SnakeBidsApp:
                 )
                 break
         if self.snakebids_config is None:
-            print(
+            raise ConfigError(
                 "Error: no snakebids.yml config file found, tried {}.".format(
                     ", ".join(SNAKEFILE_CHOICES)
-                ),
-                file=sys.stderr,
+                )
             )
-            sys.exit(1)
 
         # look for snakefile in the snakemake_dir, quit if not found
         self.snakefile = None
@@ -129,15 +144,15 @@ class SnakeBidsApp:
                 self.snakefile = os.path.join(snakemake_dir, snakefile_path)
                 break
         if self.snakefile is None:
-            print(
+            raise ConfigError(
                 "Error: no Snakefile found, tried {}.".format(
                     ", ".join(SNAKEFILE_CHOICES)
-                ),
-                file=sys.stderr,
+                )
             )
-            sys.exit(1)
 
         self.__load_config()
+        if self.config.get("debug", False):
+            logging.basicConfig(level=logging.DEBUG)
 
         # add path to snakefile to the config -- so workflows can grab files
         # relative to the snakefile folder
@@ -179,6 +194,17 @@ class SnakeBidsApp:
                 description="Snakebids helps build BIDS Apps with Snakemake"
             )
 
+        # add option for printing out snakemake usage
+        parser.add_argument(
+            "--help_snakemake",
+            nargs=0,
+            action=SnakemakeHelpAction,
+            help=(
+                "Options to Snakemake can also be passed directly at the "
+                "command-line, use this to print Snakemake usage"
+            ),
+        )
+
         # create parser group for app options
         app_group = parser.add_argument_group(
             "SNAKEBIDS", "Options for snakebids app"
@@ -252,17 +278,18 @@ class SnakeBidsApp:
         return parser
 
     def __parse_args(self):
-        # use combined parser first - to show snakebids+snakemake opts
-        self.parser_include_snakemake.parse_args()
 
-        # then use snakebids parser to actually parse the arguments
+        # use snakebids parser to parse the known arguments
+        # will pass the rest of args when running snakemake
         all_args = self.parser.parse_known_args()
 
         args = all_args[0]
         snakemake_args = all_args[1]
 
-        # add arguments to config
+        # add snakebids arguments to config
         self.config.update(args.__dict__)
+
+        # add snakemake arguments to config
         self.config.update({"snakemake_args": snakemake_args})
 
         # argparse adds filter_{input_type} to the config
